# Coyaml

<!-- 
Brief project introduction:
- What Coyaml is
- Key features (dot-notation, Pydantic validation, templates)
-->

## Quick Links

- **Installation** → installation.md  
- **Quickstart** → quickstart.md  
- **Configuration & Templates** → configuration.md  
- **Tutorials** → tutorials/first-steps.md  
- **API Reference** → api/modules.md  
- **Contributing** → contributing.md  
- **Changelog** → changelog.md
